==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/nl.js <==
﻿/*
 * PLUGIN RSS
 *
 * Dutch language file.
 *
 * Author: rascalli (rascallim@gmail.com)
 */

 theUILang.addRSS			= "Toevoegen RSS-feed";
 theUILang.feedURL			= "Feed URL";
 theUILang.alias			= "Naam RSS-Feed";
 theUILang.rssAuto			= "automatisch downloaden items gepubliceerd in feed";
 theUILang.allFeeds			= "Alle feeds";
 theUILang.incorrectURL 		= "Geeft u alstublieft de juiste URL";
 theUILang.cantFetchRSS 		= "Fout bij het laden van de feed.";
 theUILang.rssAlreadyExist		= "Feed bestaat reeds.";
 theUILang.rssDontExist 		= "Feed bestaat niet. ";
 theUILang.rssCantLoadTorrent		= "Fout bij het laden van de torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Reeds geladen";
 theUILang.rssMenuLoad			= "Laad";
 theUILang.rssMenuOpen			= "Open in browser";
 theUILang.rssMenuClearHistory		= "Geschiedenis wissen";
 theUILang.rssMenuAddToFilter		= "Voeg toe aan favorieten";
 theUILang.rssMenuManager		= "RSS Manager";
 theUILang.rssMenuRefresh		= "Update feed";
 theUILang.rssMenuDisable		= "Schakel feed uit";
 theUILang.rssMenuEnable		= "Schakel feed in";
 theUILang.rssMenuEdit			= "Bewerk feed";
 theUILang.rssMenuDelete		= "Verwijder feed";
 theUILang.rssDeletePrompt		= "Wilt u werkelijk de geselecteerde feed verwijderen?";
 theUILang.rssNewFilter 		= "Nieuw filter";
 theUILang.rssFilter			= "Filter";
 theUILang.rssAddFilter 		= "Toevoegen";
 theUILang.rssDelFilter 		= "Verwijderen";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Filter instellingen";
 theUILang.rssIncorrectFilter		= "Filter is onjuist.";
 theUILang.foundedByFilter		= "Matches";
 theUILang.rssExclude			= "Uitsluiten";
 theUILang.rssStatusError		= "Laadd error";
 theUILang.rssFeeds			= "feeds";
 theUILang.rssCheckTitle		= "Controleer titel veld";
 theUILang.rssCheckDescription		= "Controleer het beschrijving veld";
 theUILang.rssCheckLink 		= "Controleer link veld";
 theUILang.rssMinInterval		= "Min interval";
 theUILang.rssIntervalAlways		= "(match altijd)";
 theUILang.rssIntervalOnce		= "(match slechts een keer)";
 theUILang.rssInterval12h		= "12 uur";
 theUILang.rssInterval1d		= "1 dag";
 theUILang.rssInterval2d		= "2 dagen";
 theUILang.rssInterval3d		= "3 dagen";
 theUILang.rssInterval4d		= "4 dagen";
 theUILang.rssInterval6d		= "6 dagen";
 theUILang.rssInterval1w		= "1 week";
 theUILang.rssInterval2w		= "2 weken";
 theUILang.rssInterval3w		= "3 weken";
 theUILang.rssInterval1m		= "1 maand";
 theUILang.rssClearFilter		= "Reset";
 theUILang.rssMarkAs			= "Markeer als";
 theUILang.rssAsLoaded			= "Geladen";
 theUILang.rssAsUnloaded		= "Uitgeschakeld";
 theUILang.addRSSGroup			= "Toevoegen RSS groep";
 theUILang.editRSSGroup 		= "Bewerk RSS Groep";
 theUILang.addRSSGroupContent		= "Inhoud";
 theUILang.rssMenuGroupDisable		= "Uitzetten groep";
 theUILang.rssMenuGroupRefresh		= "Update groep";
 theUILang.rssMenuGroupEnable		= "Aanzetten groep";
 theUILang.rssMenuGroupEdit		= "Bewerk groep";
 theUILang.rssMenuGroupDelete		= "Verwijder groep";
 theUILang.rssMenuGroupContentsDelete	= "Verwijder Inhoud";
 theUILang.rssDeleteGroupPrompt 	= "Weet u zeker dat u de geslecteerde groep wilt verwijderen ?";
 theUILang.rssDeleteGroupContentsPrompt = "Weet u zeker dat u de geslecteerde groep + inhoud wilt verwijderen?";
 theUILang.rssAllFiters 		= "Alle filters";
 theUILang.rssUpdateInterval 		= "Update interval";
 theUILang.Directories			= "Directories";
 theUILang.Labels			= "Labels";

thePlugins.get("rss").langLoaded();

==> rutorrent-5.1.1.tar.gz: ruTorrent-5.1.1/plugins/rss/lang/nl.js <==
﻿/*
 * PLUGIN RSS
 *
 * Dutch language file.
 *
 * Author: rascalli (rascallim@gmail.com)
 */

 theUILang.addRSS			= "Toevoegen RSS-feed";
 theUILang.feedURL			= "Feed URL";
 theUILang.alias			= "Naam RSS-Feed";
 theUILang.rssAuto			= "automatisch downloaden items gepubliceerd in feed";
 theUILang.allFeeds			= "Alle feeds";
 theUILang.incorrectURL			= "Geeft u alstublieft de juiste URL.";
 theUILang.cantFetchRSS			= "Fout bij het laden van de feed.";
 theUILang.rssAlreadyExist		= "Feed bestaat reeds.";
 theUILang.rssDontExist			= "Feed bestaat niet.";
 theUILang.rssCantLoadTorrent		= "Fout bij het laden van de torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Reeds geladen";
 theUILang.rssMenuLoad			= "Laad";
 theUILang.rssMenuOpen			= "Open in browser";
 theUILang.rssMenuClearHistory		= "Geschiedenis wissen";
 theUILang.rssMenuAddToFilter		= "Voeg toe aan favorieten";
 theUILang.rssMenuManager		= "RSS Manager";
 theUILang.rssMenuRefresh		= "Update feed";
 theUILang.rssMenuDisable		= "Schakel feed uit";
 theUILang.rssMenuEnable		= "Schakel feed in";
 theUILang.rssMenuEdit			= "Bewerk feed";
 theUILang.rssMenuDelete		= "Verwijder feed";
 theUILang.rssDeletePrompt		= "Wilt u werkelijk de geselecteerde feed verwijderen?";
 theUILang.rssNewFilter			= "Nieuw filter";
 theUILang.rssFilter			= "Filter";
 theUILang.rssAddFilter			= "Toevoegen";
 theUILang.rssDelFilter			= "Verwijderen";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Filter instellingen";
 theUILang.rssIncorrectFilter		= "Filter is onjuist.";
 theUILang.foundedByFilter		= "Matches";
 theUILang.rssExclude			= "Uitsluiten";
 theUILang.rssStatusError		= "Laadd error";
 theUILang.rssFeeds			= "feeds";
 theUILang.rssCheckTitle		= "Controleer titel veld";
 theUILang.rssCheckDescription		= "Controleer het beschrijving veld";
 theUILang.rssCheckLink			= "Controleer link veld";
 theUILang.rssMinInterval		= "Min interval";
 theUILang.rssIntervalAlways		= "(match altijd)";
 theUILang.rssIntervalOnce		= "(match slechts een keer)";
 theUILang.rssInterval12h		= "12 uur";
 theUILang.rssInterval1d		= "1 dag";
 theUILang.rssInterval2d		= "2 dagen";
 theUILang.rssInterval3d		= "3 dagen";
 theUILang.rssInterval4d		= "4 dagen";
 theUILang.rssInterval6d		= "6 dagen";
 theUILang.rssInterval1w		= "1 week";
 theUILang.rssInterval2w		= "2 weken";
 theUILang.rssInterval3w		= "3 weken";
 theUILang.rssInterval1m		= "1 maand";
 theUILang.rssClearFilter		= "Reset";
 theUILang.rssMarkAs			= "Markeer als";
 theUILang.rssAsLoaded			= "Geladen";
 theUILang.rssAsUnloaded		= "Uitgeschakeld";
 theUILang.addRSSGroup			= "Toevoegen RSS groep";
 theUILang.editRSSGroup			= "Bewerk RSS Groep";
 theUILang.addRSSGroupContent		= "Inhoud";
 theUILang.rssMenuGroupDisable		= "Uitzetten groep";
 theUILang.rssMenuGroupRefresh		= "Update groep";
 theUILang.rssMenuGroupEnable		= "Aanzetten groep";
 theUILang.rssMenuGroupEdit		= "Bewerk groep";
 theUILang.rssMenuGroupDelete		= "Verwijder groep";
 theUILang.rssMenuGroupContentsDelete	= "Verwijder Inhoud";
 theUILang.rssDeleteGroupPrompt		= "Weet u zeker dat u de geslecteerde groep wilt verwijderen?";
 theUILang.rssDeleteGroupContentsPrompt	= "Weet u zeker dat u de geslecteerde groep + inhoud wilt verwijderen?";
 theUILang.rssAllFiters			= "Alle filters";
 theUILang.rssUpdateInterval		= "Update interval";
 theUILang.rssShowErrorsDelayed		= "Delay RSS error notification until the log tab or RSS feed is visible";
 theUILang.Directories			= "Directories";
 theUILang.Labels			= "Labels";
 theUILang.rssPatternExample		= "Regular Expression Example";

thePlugins.get("rss").langLoaded();
